//
// QPerforce is a gui interface to the perforce revision control
// system. It is based on the qt library, and should be easily portable
// across any platform that has this toolkit available.
// 
// Copyright (C) 2002 Jacob Gladish
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
#ifndef __I_UPDATEABLE_H__
#define __I_UPDATEABLE_H__

#include <qdatetime.h>

class IUpdateable 
{

public:  

  IUpdateable() {
    _nextUpdateTime = QDateTime::currentDateTime();
    // cache is stale very ten minutes by default.
    _maxCacheLifeSeconds = static_cast< int >( 60 * 10 );
  }

  inline bool cacheIsStale();
  inline void setMaxCacheLife( int seconds );
  inline int  getMaxCacheLife( void ) const;

  void refreshCache();
  void updateCacheIfNecessary();

protected:

  virtual void updateCache()  = 0;
  
  QDateTime _nextUpdateTime;
  int _maxCacheLifeSeconds;

};

inline bool IUpdateable::cacheIsStale()
{
  return QDateTime::currentDateTime() > _nextUpdateTime;
}

inline void IUpdateable::setMaxCacheLife( int seconds )
{
  _maxCacheLifeSeconds = seconds;
}


inline int IUpdateable::getMaxCacheLife( void ) const
{
  return _maxCacheLifeSeconds;
}


#endif




